-- config.lua
-- Apr 2017
-- Configuration Options
-- 
-- You should be able to leave most of the settings here as defaults.
-- The only thing you definitely want to change are the welcome messages.

--------------------------------------------------------------------------------
-- Messages
--------------------------------------------------------------------------------

WELCOME_MSG = "Welcome to OarcScenario Server, hosted by NFO Servers Admin by Philip017"
GAME_MODE_MSG = "Rocket Silo is far off. Trains RHD, signals outside."
MODULES_ENABLED = "Beware the invading Bugs, as they will return to reclaim their lands."

WELCOME_MSG_TITLE = "Welcome to Oarc NFO Server. Join us on discord: discord.gg/TPYxRrS"
WELCOME_MSG1 = "Rules: Be polite. Ask before changing other players's stuff. Have fun!"
WELCOME_MSG2 = "Bot run bases may have their bases adjusted by admin for continued bot beeping."

OTHER_MSG1 = "Repeaded connect and disconnect over a small time frame may get you banned."
OTHER_MSG2 = "You are requested to help launch rockets, if your base is able."

WELCOME_MSG3 = "Due to the way this scenario works, it may take some time"
WELCOME_MSG4 = "for the land around your new spawn area to generate..."
WELCOME_MSG5 = "Please wait for 10-20 seconds when you select your first spawn."
WELCOME_MSG6 = "Pending any major bugs, this map will be up until 60+ rockets have been launched."

SPAWN_MSG1 = "Current Spawn Mode: HARDCORE WILDERNESS (BETA)"
SPAWN_MSG2 = "In this mode, there is no default spawn. Everyone starts in the wild!"
SPAWN_MSG3 = "Resources are spread out far apart but are quite rich."

-- These are my specific welcome messages that get used only if I am the user
-- that creates the game.
SERVER_OWNER_IS_OARC = false -- This should be false for you, it's just a convenience for me.
WELCOME_MSG_OARC = "Welcome to Oarc's official server! Join the discord here: discord.gg/TPYxRrS"
WELCOME_MSG_TITLE_OARC = "Welcome to Oarc's Server - Happy 0.15.X Bug Fest!"


--------------------------------------------------------------------------------
-- Module Enables
-- These enables are not fully tested! For example, disable separate spawns
-- will probably break the frontier rocket silo mode
--------------------------------------------------------------------------------

-- Frontier style rocket silo mode
FRONTIER_ROCKET_SILO_MODE = true

-- Separate spawns
-- This is the core of the mod. Probably not a good idea to disable it.
ENABLE_SEPARATE_SPAWNS = true

-- Enable Scenario version of RSO
-- You can reconfigure the RSO resource settings in the RSO files if you want to
ENABLE_RSO = true

-- Enable Undecorator
-- Removes decorative items to reduce save file size.
ENABLE_UNDECORATOR = true

-- Enable Tags
ENABLE_TAGS = true

-- Enable Long Reach
ENABLE_LONGREACH = true

-- Enable Autofill
ENABLE_AUTOFILL = true

-- Enable Playerlist
ENABLE_PLAYER_LIST = true

-- Enable Gravestone Chests
ENABLE_GRAVESTONE_ON_DEATH = false
ENABLE_GRAVESTONE_ON_LEAVING = false -- (Items dumped into chest when you leave.)
GRAVESTONE_LEAVE_TIME_IN_MINUTES = 120 -- Time in Minutes before you get to keep your items
GRAVESTONE_LEAVE_TIME = TICKS_PER_MINUTE * GRAVESTONE_LEAVE_TIME_IN_MINUTES

-- Enable quick start items
ENABLE_POWER_ARMOR_QUICK_START = true

-- Enable shared vision between teams (all teams are still COOP)
ENABLE_SHARED_TEAM_VISION = false

--------------------------------------------------------------------------------
-- Spawn Options
--------------------------------------------------------------------------------

---------------------------------------
-- Starting Items
---------------------------------------
-- Items provided to the player the first time they join ("quick start" commented out)
PLAYER_SPAWN_START_ITEMS = {
    {name="submachine-gun", count=1},
    {name="firearm-magazine", count=100},
    {name="iron-plate", count=20},
    {name="burner-mining-drill", count = 1},
    {name="stone-furnace", count = 1},
	{name="steel-axe", count = 3},
}

-- Items provided after EVERY respawn (disabled by default)
PLAYER_RESPAWN_START_ITEMS = {
    {name="burner-mining-drill", count = 1},
    {name="stone-furnace", count = 1},
}

---------------------------------------
-- Distance Options
---------------------------------------

-- This is the radius, in chunks, that a spawn area is from any other generated
-- chunks. It ensures the spawn area isn't too near generated/explored/existing
-- area. The larger you make this, the further away players will spawn from 
-- generated map area (even if it is not visible on the map!).
CHECK_SPAWN_UNGENERATED_CHUNKS_RADIUS = 20 --5

-- Near Distance in chunks
NEAR_MIN_DIST = 25 --50
NEAR_MAX_DIST = 75 --125
                   --
-- Far Distance in chunks
FAR_MIN_DIST = 125 --50
FAR_MAX_DIST = 200 --125
          
---------------------------------------
-- Resource & Spawn Circle Options
---------------------------------------

-- Create a circle of land area for the spawn
-- This is the radius (I think?) in TILES.
ENFORCE_LAND_AREA_TILE_DIST = 56

-- Start resource amounts
START_IRON_AMOUNT = 500
START_COPPER_AMOUNT = 500
START_STONE_AMOUNT = 500
START_COAL_AMOUNT = 500
START_URANIUM_AMOUNT = 500
START_OIL_AMOUNT = 2000000

-- Start resource shape
-- If this is true, it will be a circle
-- If false, it will be a square
ENABLE_RESOURCE_SHAPE_CIRCLE = true

-- Create a circle of land area for the spawn
ENFORCE_LAND_AREA_TILE_DIST = 56

-- Start resource position and size
-- Position is relative to player starting location
START_RESOURCE_STONE_POS_X = -29
START_RESOURCE_STONE_POS_Y = -46
START_RESOURCE_STONE_SIZE = 19

START_RESOURCE_COAL_POS_X = -44
START_RESOURCE_COAL_POS_Y = -26
START_RESOURCE_COAL_SIZE = 19

START_RESOURCE_COPPER_POS_X = -44
START_RESOURCE_COPPER_POS_Y = -5
START_RESOURCE_COPPER_SIZE = 19

START_RESOURCE_IRON_POS_X = -30
START_RESOURCE_IRON_POS_Y = 16
START_RESOURCE_IRON_SIZE = 33

START_RESOURCE_URANIUM_POS_X = 19
START_RESOURCE_URANIUM_POS_Y = -40
START_RESOURCE_URANIUM_SIZE = 19 -- 0 Disabled by default.

WATER_SPAWN_OFFSET_X = -8
WATER_SPAWN_OFFSET_Y = -43
WATER_SPAWN_LENGTH = 12

-- Specify 2 oil spot locations
START_RESOURCE_OIL_A_POS_X = 12
START_RESOURCE_OIL_A_POS_Y = -43
START_RESOURCE_OIL_B_POS_X = 15
START_RESOURCE_OIL_B_POS_Y = -43


-- Force the land area circle at the spawn to be fully grass
ENABLE_SPAWN_FORCE_GRASS = true

-- Set this to true for the spawn area to be surrounded by a circle of trees
SPAWN_TREE_CIRCLE_ENABLED = false

-- Set this to true for the spawn area to be surrounded by an octagon of trees
SPAWN_TREE_OCTAGON_ENABLED = true

---------------------------------------
-- Safe Spawn Area Options
---------------------------------------

-- Safe area has no aliens
-- +/- this in x and y direction
SAFE_AREA_TILE_DIST = CHUNK_SIZE*12

-- Warning area has reduced aliens
-- +/- this in x and y direction
WARNING_AREA_TILE_DIST = CHUNK_SIZE*20

-- 1 : X (spawners alive : spawners destroyed) in this area
WARN_AREA_REDUCTION_RATIO = 15


---------------------------------------
-- Other Forces/Teams Options
---------------------------------------

-- Separate teams
-- This allows you to join your own force/team. Everyone is still COOP/PvE, all
-- teams are friendly and cease-fire.
ENABLE_SEPARATE_TEAMS = false

-- Main force is what default players join
MAIN_FORCE = "main_force"

-- Enable if people can spawn at the main base
ENABLE_DEFAULT_SPAWN = false

-- Enable if people can allow others to join their base
ENABLE_SHARED_SPAWNS = true
MAX_ONLINE_PLAYERS_AT_SHARED_SPAWN = 3

---------------------------------------
-- Special Action Cooldowns
---------------------------------------
RESPAWN_COOLDOWN_IN_MINUTES = 60
RESPAWN_COOLDOWN_TICKS = TICKS_PER_MINUTE * RESPAWN_COOLDOWN_IN_MINUTES

-- Require playes to be online for at least 5 minutes
-- Else their character is removed and their spawn point is freed up for use
MIN_ONLIME_TIME_IN_MINUTES = 15
MIN_ONLINE_TIME = TICKS_PER_MINUTE * MIN_ONLIME_TIME_IN_MINUTES


--------------------------------------------------------------------------------
-- Alien Options
--------------------------------------------------------------------------------

-- Enable/Disable enemy expansion (Applies to RSO as well!)
ENEMY_EXPANSION = true

-- Divide the alien factors by this number to reduce it (or multiply if < 1)
ENEMY_POLLUTION_FACTOR_DIVISOR = 10
ENEMY_DESTROY_FACTOR_DIVISOR = 5


--------------------------------------------------------------------------------
-- Frontier Rocket Silo Options
--------------------------------------------------------------------------------

SILO_CHUNK_DISTANCE_X = 250
SILO_DISTANCE_X = SILO_CHUNK_DISTANCE_X*CHUNK_SIZE + CHUNK_SIZE/2
SILO_DISTANCE_Y = 16

-- Should be in the middle of a chunk
SILO_POSITION = {x = SILO_DISTANCE_X, y = SILO_DISTANCE_Y}

-- If this is enabled, the static position is ignored.
ENABLE_RANDOM_SILO_POSITION = true

--------------------------------------------------------------------------------
-- Long Reach Options
--------------------------------------------------------------------------------

BUILD_DIST_BONUS = 30
REACH_DIST_BONUS = BUILD_DIST_BONUS
RESOURCE_DIST_BONUS = 3

--------------------------------------------------------------------------------
-- Autofill Options
--------------------------------------------------------------------------------

AUTOFILL_TURRET_AMMO_QUANTITY = 20

--------------------------------------------------------------------------------
-- Use rso_config and rso_resource_config for RSO config settings
--------------------------------------------------------------------------------
-- Don't touch unless you know what you're doing...
-- When using RSO, all resources MUST BE SET TO SIZE=NONE!
--------------------------------------------------------------------------------
MAP_SETTINGS_RSO_TERRAIN_SEGMENTATION = "medium" -- Frequency of water
MAP_SETTINGS_RSO_WATER = "high" -- Size of water patches
MAP_SETTINGS_RSO_PEACEFUL = false -- Peaceful mode for biters/aliens
MAP_SETTINGS_RSO_SEED = math.random(999999999) -- Default is randomized map
MAP_SETTINGS_RSO_STARTING_AREA = "very-low" -- Does not affect Oarc spawn sizes.

-------------------------------------------------------------------------------
-- DEBUG
--------------------------------------------------------------------------------

-- DEBUG prints for me
global.oarcDebugEnabled = false
